@@ -2,7 +2,7 @@ package HTTP::OAI;
 
 use strict;
 
-our $VERSION = '4.02';
+our $VERSION = '4.04';
 
 use constant OAI_NS => 'http://www.openarchives.org/OAI/2.0/';
 
@@ -100,6 +100,14 @@ __END__
 
 HTTP::OAI - API for the OAI-PMH
 
+=begin markdown
+
+# STATUS
+
+[![Build Status](https://travis-ci.org/LibreCat/perl-oai-lib.svg?branch=master)](https://travis-ci.org/LibreCat/perl-oai-lib)
+
+=end markdown
+
 =head1 DESCRIPTION
 
 This is a stub module, you probably want to look at
@@ -113,7 +121,7 @@ http://www.openarchives.org/tools/tools.html.
 
 Ed Summers L<Net::OAI::Harvester> module.
 
-=head1 AUTHOR
+=head1 LICENSE
 
 Copyright 2004-2010 Tim Brody <tdb2@ecs.soton.ac.uk>, University of
 Southampton.
