@@ -4,6 +4,8 @@ use base HTTP::OAI::UserAgent;
 
 use strict;
 
+our $VERSION = '4.04';
+
 sub new {
 	my ($class,%args) = @_;
 	my %ARGS = %args;
@@ -33,7 +35,7 @@ sub repository { shift->_elem('repository',@_) }
 
 sub baseURL {
 	my $self = shift;
-	return @_ ? 
+	return @_ ?
 		$self->repository->baseURL(URI->new(shift)->canonical) :
 		$self->repository->baseURL();
 }
@@ -56,7 +58,7 @@ sub _list
 		last RESUME if !$token->resumptionToken;
 		local $self->{recursion};
 		$r = $self->_oai(
-			$r->{onRecord},
+			onRecord => $r->{onRecord},
 			handlers => $r->handlers,
 			verb => $r->verb,
 			resumptionToken => $token->resumptionToken,
